@@ -126,7 +126,7 @@ def parse_brand(p: Product, selector: parsel.Selector = None):
         return product_overview_feature_div(selector, "Brand")
 
     def s2() -> str:
-        s = selector.xpath("//a[@id='bylineInfo']/text()").re_first("Brand: (.*)")
+        s = selector.xpath("//a[@id='bylineInfo']/text()").re_first(".*?: (.*)")
         s = s or selector.xpath("//a[@id='bylineInfo']/text()").re_first("Visit the (.*) Store")
         return s
 
@@ -163,7 +163,7 @@ def parse_price(p: Product, selector: parsel.Selector = None):
             price = t.at["origin", "price"]
         return "" if pandas.isna(price) else str(price)
 
-    prices_str = s2() or s1()
+    prices_str = (s2() or s1()).strip()
     prices: Union[None, list] = parse_number(prices_str.replace(",", ""), first=False)
     if prices is None or len(prices) == 0:
         p.price_min = None
@@ -447,8 +447,10 @@ def parse_thumbnail(p: Product, selector: parsel.Selector = None):
     thumbnail = thumbnail or selector.xpath("//div[@id='imageBlockThumbs']//img/@src").getall()
     if len(thumbnail) < 1:
         p.thumbnail = None
+        p.thumbnails = None
     else:
         p.thumbnail = thumbnail[0]
+        p.thumbnails = list(filter(lambda t: "transparent-pixel" not in t, thumbnail))
 
 
 def parse_category(p: Product, selector: parsel.Selector = None):
