@@ -7,3 +7,5 @@ class Shop(BaseModel):
     seller: Optional[str]
     name: Optional[str]
     address: Optional[str]
+    stars: Optional[float]
+    ratings: Optional[int]
